==> nifi-2.0.0-source-release.zip: nifi-2.0.0/nifi-frontend/src/main/frontend/apps/nifi/src/app/pages/summary/ui/output-port-status-listing/output-port-status-listing.component.spec.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { ComponentFixture, TestBed } from '@angular/core/testing';

import { OutputPortStatusListing } from './output-port-status-listing.component';
import { PortStatusTable } from '../common/port-status-table/port-status-table.component';
import { SummaryTableFilterModule } from '../common/summary-table-filter/summary-table-filter.module';
import { NoopAnimationsModule } from '@angular/platform-browser/animations';
import { provideMockStore } from '@ngrx/store/testing';
import { initialState } from '../../state/summary-listing/summary-listing.reducer';

describe('OutputPortStatusListing', () => {
    let component: OutputPortStatusListing;
    let fixture: ComponentFixture<OutputPortStatusListing>;

    beforeEach(() => {
        TestBed.configureTestingModule({
            declarations: [OutputPortStatusListing],
            imports: [PortStatusTable, SummaryTableFilterModule, NoopAnimationsModule],
            providers: [provideMockStore({ initialState })]
        });
        fixture = TestBed.createComponent(OutputPortStatusListing);
        component = fixture.componentInstance;
        fixture.detectChanges();
    });

    it('should create', () => {
        expect(component).toBeTruthy();
    });
});

==> nifi-2.6.0-source-release.zip: nifi-2.6.0/nifi-frontend/src/main/frontend/apps/nifi/src/app/pages/summary/ui/output-port-status-listing/output-port-status-listing.component.spec.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { ComponentFixture, TestBed } from '@angular/core/testing';

import { OutputPortStatusListing } from './output-port-status-listing.component';
import { NoopAnimationsModule } from '@angular/platform-browser/animations';
import { provideMockStore } from '@ngrx/store/testing';
import { initialState } from '../../state/summary-listing/summary-listing.reducer';

describe('OutputPortStatusListing', () => {
    let component: OutputPortStatusListing;
    let fixture: ComponentFixture<OutputPortStatusListing>;

    beforeEach(() => {
        TestBed.configureTestingModule({
            imports: [OutputPortStatusListing, NoopAnimationsModule],
            providers: [provideMockStore({ initialState })]
        });
        fixture = TestBed.createComponent(OutputPortStatusListing);
        component = fixture.componentInstance;
        fixture.detectChanges();
    });

    it('should create', () => {
        expect(component).toBeTruthy();
    });
});
